==========
Annotation
==========

Annotation commands are used to create, position, and modify viewport annotations.


Create annotations
------------------

.. automethod:: abaqus.Annotation.AnimationUserData.AnimationUserData.Arrow

.. automethod:: abaqus.Annotation.AnimationUserData.AnimationUserData.Text

.. automethod:: abaqus.Annotation.AnimationUserData.AnimationUserData.XYData


Object features
---------------

Annotation
~~~~~~~~~~

.. autoclass:: abaqus.Annotation.Annotation.Annotation
    :members:

    .. autoclasstoc::

AnnotationsToPlotArray
~~~~~~~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.Annotation.AnnotationsToPlotArray.AnnotationsToPlotArray
    :members:

    .. autoclasstoc::

AnnotationViewport
~~~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.Annotation.AnnotationViewport.AnnotationViewport
    :members:

    .. autoclasstoc::

Arrow
~~~~~

.. autoclass:: abaqus.Annotation.Arrow.Arrow
    :members:

    .. autoclasstoc::

Text
~~~~

.. autoclass:: abaqus.Annotation.Text.Text
    :members: